## Version 1.4.0 (2018/10/23)

### Issues Closed

* [Issue 36](https://github.com/pytroll/pyorbital/issues/36) - Issue(s) with get_next_passes
* [Issue 34](https://github.com/pytroll/pyorbital/issues/34) - Get root secant converging to wrong solution ([PR 35](https://github.com/pytroll/pyorbital/pull/35))
* [Issue 30](https://github.com/pytroll/pyorbital/issues/30) - get_observer_look turns xarray.DataArray objects into dask.array objects
* [Issue 29](https://github.com/pytroll/pyorbital/issues/29) - URL error
* [Issue 27](https://github.com/pytroll/pyorbital/issues/27) - satellite.get_lonlatalt(now) returns wrong longitude with numpy < 1.11
* [Issue 18](https://github.com/pytroll/pyorbital/issues/18) - Sun-satellite angle ranges are not consistent

In this release 6 issues were closed.

### Pull Requests Merged

#### Bugs fixed

* [PR 39](https://github.com/pytroll/pyorbital/pull/39) - Bugfix python3
* [PR 35](https://github.com/pytroll/pyorbital/pull/35) - Use Scipy brentq method instead of secant method to perform root-finding ([34](https://github.com/pytroll/pyorbital/issues/34))

#### Features added

* [PR 37](https://github.com/pytroll/pyorbital/pull/37) - Switch to versioneer
* [PR 33](https://github.com/pytroll/pyorbital/pull/33) - Remove Develop branch

In this release 4 pull requests were closed.
